# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TrackedDownloadState(str, Enum):
    """
    TrackedDownloadState
    """

    """
    allowed enum values
    """
    DOWNLOADING = 'downloading'
    IMPORTPENDING = 'importPending'
    IMPORTING = 'importing'
    IMPORTED = 'imported'
    FAILEDPENDING = 'failedPending'
    FAILED = 'failed'
    IGNORED = 'ignored'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TrackedDownloadState from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.language import Language
from whisparr.models.quality_model import QualityModel
from typing import Optional, Set
from typing_extensions import Self

class MovieFileListResource(BaseModel):
    """
    MovieFileListResource
    """ # noqa: E501
    movie_file_ids: Optional[List[StrictInt]] = Field(default=None, alias="movieFileIds")
    languages: Optional[List[Language]] = None
    quality: Optional[QualityModel] = None
    edition: Optional[StrictStr] = None
    release_group: Optional[StrictStr] = Field(default=None, alias="releaseGroup")
    scene_name: Optional[StrictStr] = Field(default=None, alias="sceneName")
    indexer_flags: Optional[StrictInt] = Field(default=None, alias="indexerFlags")
    __properties: ClassVar[List[str]] = ["movieFileIds", "languages", "quality", "edition", "releaseGroup", "sceneName", "indexerFlags"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MovieFileListResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item_languages in self.languages:
                if _item_languages:
                    _items.append(_item_languages.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # set to None if movie_file_ids (nullable) is None
        # and model_fields_set contains the field
        if self.movie_file_ids is None and "movie_file_ids" in self.model_fields_set:
            _dict['movieFileIds'] = None

        # set to None if languages (nullable) is None
        # and model_fields_set contains the field
        if self.languages is None and "languages" in self.model_fields_set:
            _dict['languages'] = None

        # set to None if edition (nullable) is None
        # and model_fields_set contains the field
        if self.edition is None and "edition" in self.model_fields_set:
            _dict['edition'] = None

        # set to None if release_group (nullable) is None
        # and model_fields_set contains the field
        if self.release_group is None and "release_group" in self.model_fields_set:
            _dict['releaseGroup'] = None

        # set to None if scene_name (nullable) is None
        # and model_fields_set contains the field
        if self.scene_name is None and "scene_name" in self.model_fields_set:
            _dict['sceneName'] = None

        # set to None if indexer_flags (nullable) is None
        # and model_fields_set contains the field
        if self.indexer_flags is None and "indexer_flags" in self.model_fields_set:
            _dict['indexerFlags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MovieFileListResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "movieFileIds": obj.get("movieFileIds"),
            "languages": [Language.from_dict(_item) for _item in obj["languages"]] if obj.get("languages") is not None else None,
            "quality": QualityModel.from_dict(obj["quality"]) if obj.get("quality") is not None else None,
            "edition": obj.get("edition"),
            "releaseGroup": obj.get("releaseGroup"),
            "sceneName": obj.get("sceneName"),
            "indexerFlags": obj.get("indexerFlags")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from whisparr.models.custom_format_resource import CustomFormatResource
from whisparr.models.download_protocol import DownloadProtocol
from whisparr.models.language import Language
from whisparr.models.quality_model import QualityModel
from typing import Optional, Set
from typing_extensions import Self

class ReleaseResource(BaseModel):
    """
    ReleaseResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    guid: Optional[StrictStr] = None
    quality: Optional[QualityModel] = None
    custom_formats: Optional[List[CustomFormatResource]] = Field(default=None, alias="customFormats")
    custom_format_score: Optional[StrictInt] = Field(default=None, alias="customFormatScore")
    quality_weight: Optional[StrictInt] = Field(default=None, alias="qualityWeight")
    age: Optional[StrictInt] = None
    age_hours: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="ageHours")
    age_minutes: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="ageMinutes")
    size: Optional[StrictInt] = None
    indexer_id: Optional[StrictInt] = Field(default=None, alias="indexerId")
    indexer: Optional[StrictStr] = None
    release_group: Optional[StrictStr] = Field(default=None, alias="releaseGroup")
    sub_group: Optional[StrictStr] = Field(default=None, alias="subGroup")
    release_hash: Optional[StrictStr] = Field(default=None, alias="releaseHash")
    title: Optional[StrictStr] = None
    scene_source: Optional[StrictBool] = Field(default=None, alias="sceneSource")
    movie_titles: Optional[List[StrictStr]] = Field(default=None, alias="movieTitles")
    languages: Optional[List[Language]] = None
    mapped_movie_id: Optional[StrictInt] = Field(default=None, alias="mappedMovieId")
    approved: Optional[StrictBool] = None
    temporarily_rejected: Optional[StrictBool] = Field(default=None, alias="temporarilyRejected")
    rejected: Optional[StrictBool] = None
    tmdb_id: Optional[StrictInt] = Field(default=None, alias="tmdbId")
    imdb_id: Optional[StrictInt] = Field(default=None, alias="imdbId")
    rejections: Optional[List[StrictStr]] = None
    publish_date: Optional[datetime] = Field(default=None, alias="publishDate")
    comment_url: Optional[StrictStr] = Field(default=None, alias="commentUrl")
    download_url: Optional[StrictStr] = Field(default=None, alias="downloadUrl")
    info_url: Optional[StrictStr] = Field(default=None, alias="infoUrl")
    download_allowed: Optional[StrictBool] = Field(default=None, alias="downloadAllowed")
    release_weight: Optional[StrictInt] = Field(default=None, alias="releaseWeight")
    indexer_flags: Optional[List[StrictStr]] = Field(default=None, alias="indexerFlags")
    edition: Optional[StrictStr] = None
    magnet_url: Optional[StrictStr] = Field(default=None, alias="magnetUrl")
    info_hash: Optional[StrictStr] = Field(default=None, alias="infoHash")
    seeders: Optional[StrictInt] = None
    leechers: Optional[StrictInt] = None
    protocol: Optional[DownloadProtocol] = None
    movie_id: Optional[StrictInt] = Field(default=None, alias="movieId")
    download_client_id: Optional[StrictInt] = Field(default=None, alias="downloadClientId")
    download_client: Optional[StrictStr] = Field(default=None, alias="downloadClient")
    should_override: Optional[StrictBool] = Field(default=None, alias="shouldOverride")
    __properties: ClassVar[List[str]] = ["id", "guid", "quality", "customFormats", "customFormatScore", "qualityWeight", "age", "ageHours", "ageMinutes", "size", "indexerId", "indexer", "releaseGroup", "subGroup", "releaseHash", "title", "sceneSource", "movieTitles", "languages", "mappedMovieId", "approved", "temporarilyRejected", "rejected", "tmdbId", "imdbId", "rejections", "publishDate", "commentUrl", "downloadUrl", "infoUrl", "downloadAllowed", "releaseWeight", "indexerFlags", "edition", "magnetUrl", "infoHash", "seeders", "leechers", "protocol", "movieId", "downloadClientId", "downloadClient", "shouldOverride"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReleaseResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in custom_formats (list)
        _items = []
        if self.custom_formats:
            for _item_custom_formats in self.custom_formats:
                if _item_custom_formats:
                    _items.append(_item_custom_formats.to_dict())
            _dict['customFormats'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item_languages in self.languages:
                if _item_languages:
                    _items.append(_item_languages.to_dict())
            _dict['languages'] = _items
        # set to None if guid (nullable) is None
        # and model_fields_set contains the field
        if self.guid is None and "guid" in self.model_fields_set:
            _dict['guid'] = None

        # set to None if custom_formats (nullable) is None
        # and model_fields_set contains the field
        if self.custom_formats is None and "custom_formats" in self.model_fields_set:
            _dict['customFormats'] = None

        # set to None if indexer (nullable) is None
        # and model_fields_set contains the field
        if self.indexer is None and "indexer" in self.model_fields_set:
            _dict['indexer'] = None

        # set to None if release_group (nullable) is None
        # and model_fields_set contains the field
        if self.release_group is None and "release_group" in self.model_fields_set:
            _dict['releaseGroup'] = None

        # set to None if sub_group (nullable) is None
        # and model_fields_set contains the field
        if self.sub_group is None and "sub_group" in self.model_fields_set:
            _dict['subGroup'] = None

        # set to None if release_hash (nullable) is None
        # and model_fields_set contains the field
        if self.release_hash is None and "release_hash" in self.model_fields_set:
            _dict['releaseHash'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if movie_titles (nullable) is None
        # and model_fields_set contains the field
        if self.movie_titles is None and "movie_titles" in self.model_fields_set:
            _dict['movieTitles'] = None

        # set to None if languages (nullable) is None
        # and model_fields_set contains the field
        if self.languages is None and "languages" in self.model_fields_set:
            _dict['languages'] = None

        # set to None if mapped_movie_id (nullable) is None
        # and model_fields_set contains the field
        if self.mapped_movie_id is None and "mapped_movie_id" in self.model_fields_set:
            _dict['mappedMovieId'] = None

        # set to None if rejections (nullable) is None
        # and model_fields_set contains the field
        if self.rejections is None and "rejections" in self.model_fields_set:
            _dict['rejections'] = None

        # set to None if comment_url (nullable) is None
        # and model_fields_set contains the field
        if self.comment_url is None and "comment_url" in self.model_fields_set:
            _dict['commentUrl'] = None

        # set to None if download_url (nullable) is None
        # and model_fields_set contains the field
        if self.download_url is None and "download_url" in self.model_fields_set:
            _dict['downloadUrl'] = None

        # set to None if info_url (nullable) is None
        # and model_fields_set contains the field
        if self.info_url is None and "info_url" in self.model_fields_set:
            _dict['infoUrl'] = None

        # set to None if indexer_flags (nullable) is None
        # and model_fields_set contains the field
        if self.indexer_flags is None and "indexer_flags" in self.model_fields_set:
            _dict['indexerFlags'] = None

        # set to None if edition (nullable) is None
        # and model_fields_set contains the field
        if self.edition is None and "edition" in self.model_fields_set:
            _dict['edition'] = None

        # set to None if magnet_url (nullable) is None
        # and model_fields_set contains the field
        if self.magnet_url is None and "magnet_url" in self.model_fields_set:
            _dict['magnetUrl'] = None

        # set to None if info_hash (nullable) is None
        # and model_fields_set contains the field
        if self.info_hash is None and "info_hash" in self.model_fields_set:
            _dict['infoHash'] = None

        # set to None if seeders (nullable) is None
        # and model_fields_set contains the field
        if self.seeders is None and "seeders" in self.model_fields_set:
            _dict['seeders'] = None

        # set to None if leechers (nullable) is None
        # and model_fields_set contains the field
        if self.leechers is None and "leechers" in self.model_fields_set:
            _dict['leechers'] = None

        # set to None if movie_id (nullable) is None
        # and model_fields_set contains the field
        if self.movie_id is None and "movie_id" in self.model_fields_set:
            _dict['movieId'] = None

        # set to None if download_client_id (nullable) is None
        # and model_fields_set contains the field
        if self.download_client_id is None and "download_client_id" in self.model_fields_set:
            _dict['downloadClientId'] = None

        # set to None if download_client (nullable) is None
        # and model_fields_set contains the field
        if self.download_client is None and "download_client" in self.model_fields_set:
            _dict['downloadClient'] = None

        # set to None if should_override (nullable) is None
        # and model_fields_set contains the field
        if self.should_override is None and "should_override" in self.model_fields_set:
            _dict['shouldOverride'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReleaseResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "guid": obj.get("guid"),
            "quality": QualityModel.from_dict(obj["quality"]) if obj.get("quality") is not None else None,
            "customFormats": [CustomFormatResource.from_dict(_item) for _item in obj["customFormats"]] if obj.get("customFormats") is not None else None,
            "customFormatScore": obj.get("customFormatScore"),
            "qualityWeight": obj.get("qualityWeight"),
            "age": obj.get("age"),
            "ageHours": obj.get("ageHours"),
            "ageMinutes": obj.get("ageMinutes"),
            "size": obj.get("size"),
            "indexerId": obj.get("indexerId"),
            "indexer": obj.get("indexer"),
            "releaseGroup": obj.get("releaseGroup"),
            "subGroup": obj.get("subGroup"),
            "releaseHash": obj.get("releaseHash"),
            "title": obj.get("title"),
            "sceneSource": obj.get("sceneSource"),
            "movieTitles": obj.get("movieTitles"),
            "languages": [Language.from_dict(_item) for _item in obj["languages"]] if obj.get("languages") is not None else None,
            "mappedMovieId": obj.get("mappedMovieId"),
            "approved": obj.get("approved"),
            "temporarilyRejected": obj.get("temporarilyRejected"),
            "rejected": obj.get("rejected"),
            "tmdbId": obj.get("tmdbId"),
            "imdbId": obj.get("imdbId"),
            "rejections": obj.get("rejections"),
            "publishDate": obj.get("publishDate"),
            "commentUrl": obj.get("commentUrl"),
            "downloadUrl": obj.get("downloadUrl"),
            "infoUrl": obj.get("infoUrl"),
            "downloadAllowed": obj.get("downloadAllowed"),
            "releaseWeight": obj.get("releaseWeight"),
            "indexerFlags": obj.get("indexerFlags"),
            "edition": obj.get("edition"),
            "magnetUrl": obj.get("magnetUrl"),
            "infoHash": obj.get("infoHash"),
            "seeders": obj.get("seeders"),
            "leechers": obj.get("leechers"),
            "protocol": obj.get("protocol"),
            "movieId": obj.get("movieId"),
            "downloadClientId": obj.get("downloadClientId"),
            "downloadClient": obj.get("downloadClient"),
            "shouldOverride": obj.get("shouldOverride")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from whisparr.models.add_movie_method import AddMovieMethod
from whisparr.models.add_movie_options import AddMovieOptions
from whisparr.models.alternative_title_resource import AlternativeTitleResource
from whisparr.models.api_info_resource import ApiInfoResource
from whisparr.models.apply_tags import ApplyTags
from whisparr.models.authentication_required_type import AuthenticationRequiredType
from whisparr.models.authentication_type import AuthenticationType
from whisparr.models.auto_tagging_resource import AutoTaggingResource
from whisparr.models.auto_tagging_specification_schema import AutoTaggingSpecificationSchema
from whisparr.models.backup_resource import BackupResource
from whisparr.models.backup_type import BackupType
from whisparr.models.blocklist_bulk_resource import BlocklistBulkResource
from whisparr.models.blocklist_resource import BlocklistResource
from whisparr.models.blocklist_resource_paging_resource import BlocklistResourcePagingResource
from whisparr.models.certificate_validation_type import CertificateValidationType
from whisparr.models.collection_movie_resource import CollectionMovieResource
from whisparr.models.collection_resource import CollectionResource
from whisparr.models.collection_update_resource import CollectionUpdateResource
from whisparr.models.colon_replacement_format import ColonReplacementFormat
from whisparr.models.command import Command
from whisparr.models.command_priority import CommandPriority
from whisparr.models.command_resource import CommandResource
from whisparr.models.command_result import CommandResult
from whisparr.models.command_status import CommandStatus
from whisparr.models.command_trigger import CommandTrigger
from whisparr.models.contract_field import ContractField
from whisparr.models.credit_resource import CreditResource
from whisparr.models.credit_type import CreditType
from whisparr.models.custom_filter_resource import CustomFilterResource
from whisparr.models.custom_format_resource import CustomFormatResource
from whisparr.models.custom_format_specification_schema import CustomFormatSpecificationSchema
from whisparr.models.database_type import DatabaseType
from whisparr.models.delay_profile_resource import DelayProfileResource
from whisparr.models.disk_space_resource import DiskSpaceResource
from whisparr.models.download_client_bulk_resource import DownloadClientBulkResource
from whisparr.models.download_client_config_resource import DownloadClientConfigResource
from whisparr.models.download_client_resource import DownloadClientResource
from whisparr.models.download_protocol import DownloadProtocol
from whisparr.models.extra_file_resource import ExtraFileResource
from whisparr.models.extra_file_type import ExtraFileType
from whisparr.models.file_date_type import FileDateType
from whisparr.models.health_check_result import HealthCheckResult
from whisparr.models.health_resource import HealthResource
from whisparr.models.history_resource import HistoryResource
from whisparr.models.history_resource_paging_resource import HistoryResourcePagingResource
from whisparr.models.host_config_resource import HostConfigResource
from whisparr.models.import_exclusions_resource import ImportExclusionsResource
from whisparr.models.import_list_bulk_resource import ImportListBulkResource
from whisparr.models.import_list_config_resource import ImportListConfigResource
from whisparr.models.import_list_resource import ImportListResource
from whisparr.models.import_list_type import ImportListType
from whisparr.models.indexer_bulk_resource import IndexerBulkResource
from whisparr.models.indexer_config_resource import IndexerConfigResource
from whisparr.models.indexer_flag_resource import IndexerFlagResource
from whisparr.models.indexer_resource import IndexerResource
from whisparr.models.language import Language
from whisparr.models.language_resource import LanguageResource
from whisparr.models.localization_language_resource import LocalizationLanguageResource
from whisparr.models.log_file_resource import LogFileResource
from whisparr.models.log_resource import LogResource
from whisparr.models.log_resource_paging_resource import LogResourcePagingResource
from whisparr.models.manual_import_reprocess_resource import ManualImportReprocessResource
from whisparr.models.manual_import_resource import ManualImportResource
from whisparr.models.media_cover import MediaCover
from whisparr.models.media_cover_types import MediaCoverTypes
from whisparr.models.media_info_resource import MediaInfoResource
from whisparr.models.media_management_config_resource import MediaManagementConfigResource
from whisparr.models.metadata_config_resource import MetadataConfigResource
from whisparr.models.metadata_resource import MetadataResource
from whisparr.models.modifier import Modifier
from whisparr.models.monitor_types import MonitorTypes
from whisparr.models.movie_collection_resource import MovieCollectionResource
from whisparr.models.movie_editor_resource import MovieEditorResource
from whisparr.models.movie_file_list_resource import MovieFileListResource
from whisparr.models.movie_file_resource import MovieFileResource
from whisparr.models.movie_history_event_type import MovieHistoryEventType
from whisparr.models.movie_resource import MovieResource
from whisparr.models.movie_runtime_format_type import MovieRuntimeFormatType
from whisparr.models.movie_statistics_resource import MovieStatisticsResource
from whisparr.models.movie_status_type import MovieStatusType
from whisparr.models.naming_config_resource import NamingConfigResource
from whisparr.models.notification_resource import NotificationResource
from whisparr.models.parse_resource import ParseResource
from whisparr.models.parsed_movie_info import ParsedMovieInfo
from whisparr.models.ping_resource import PingResource
from whisparr.models.privacy_level import PrivacyLevel
from whisparr.models.profile_format_item_resource import ProfileFormatItemResource
from whisparr.models.proper_download_types import ProperDownloadTypes
from whisparr.models.provider_message import ProviderMessage
from whisparr.models.provider_message_type import ProviderMessageType
from whisparr.models.proxy_type import ProxyType
from whisparr.models.quality import Quality
from whisparr.models.quality_definition_resource import QualityDefinitionResource
from whisparr.models.quality_model import QualityModel
from whisparr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource
from whisparr.models.quality_profile_resource import QualityProfileResource
from whisparr.models.quality_source import QualitySource
from whisparr.models.queue_bulk_resource import QueueBulkResource
from whisparr.models.queue_resource import QueueResource
from whisparr.models.queue_resource_paging_resource import QueueResourcePagingResource
from whisparr.models.queue_status_resource import QueueStatusResource
from whisparr.models.rating_child import RatingChild
from whisparr.models.rating_type import RatingType
from whisparr.models.ratings import Ratings
from whisparr.models.rejection import Rejection
from whisparr.models.rejection_type import RejectionType
from whisparr.models.release_profile_resource import ReleaseProfileResource
from whisparr.models.release_resource import ReleaseResource
from whisparr.models.remote_path_mapping_resource import RemotePathMappingResource
from whisparr.models.rename_movie_resource import RenameMovieResource
from whisparr.models.rescan_after_refresh_type import RescanAfterRefreshType
from whisparr.models.revision import Revision
from whisparr.models.root_folder_resource import RootFolderResource
from whisparr.models.runtime_mode import RuntimeMode
from whisparr.models.select_option import SelectOption
from whisparr.models.sort_direction import SortDirection
from whisparr.models.source_type import SourceType
from whisparr.models.system_resource import SystemResource
from whisparr.models.tmdb_country_code import TMDbCountryCode
from whisparr.models.tag_details_resource import TagDetailsResource
from whisparr.models.tag_resource import TagResource
from whisparr.models.task_resource import TaskResource
from whisparr.models.tracked_download_state import TrackedDownloadState
from whisparr.models.tracked_download_status import TrackedDownloadStatus
from whisparr.models.tracked_download_status_message import TrackedDownloadStatusMessage
from whisparr.models.ui_config_resource import UiConfigResource
from whisparr.models.unmapped_folder import UnmappedFolder
from whisparr.models.update_changes import UpdateChanges
from whisparr.models.update_mechanism import UpdateMechanism
from whisparr.models.update_resource import UpdateResource



# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.contract_field import ContractField
from whisparr.models.provider_message import ProviderMessage
from typing import Optional, Set
from typing_extensions import Self

class MetadataResource(BaseModel):
    """
    MetadataResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    fields: Optional[List[ContractField]] = None
    implementation_name: Optional[StrictStr] = Field(default=None, alias="implementationName")
    implementation: Optional[StrictStr] = None
    config_contract: Optional[StrictStr] = Field(default=None, alias="configContract")
    info_link: Optional[StrictStr] = Field(default=None, alias="infoLink")
    message: Optional[ProviderMessage] = None
    tags: Optional[List[StrictInt]] = None
    presets: Optional[List[MetadataResource]] = None
    enable: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["id", "name", "fields", "implementationName", "implementation", "configContract", "infoLink", "message", "tags", "presets", "enable"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetadataResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in fields (list)
        _items = []
        if self.fields:
            for _item_fields in self.fields:
                if _item_fields:
                    _items.append(_item_fields.to_dict())
            _dict['fields'] = _items
        # override the default output from pydantic by calling `to_dict()` of message
        if self.message:
            _dict['message'] = self.message.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in presets (list)
        _items = []
        if self.presets:
            for _item_presets in self.presets:
                if _item_presets:
                    _items.append(_item_presets.to_dict())
            _dict['presets'] = _items
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if fields (nullable) is None
        # and model_fields_set contains the field
        if self.fields is None and "fields" in self.model_fields_set:
            _dict['fields'] = None

        # set to None if implementation_name (nullable) is None
        # and model_fields_set contains the field
        if self.implementation_name is None and "implementation_name" in self.model_fields_set:
            _dict['implementationName'] = None

        # set to None if implementation (nullable) is None
        # and model_fields_set contains the field
        if self.implementation is None and "implementation" in self.model_fields_set:
            _dict['implementation'] = None

        # set to None if config_contract (nullable) is None
        # and model_fields_set contains the field
        if self.config_contract is None and "config_contract" in self.model_fields_set:
            _dict['configContract'] = None

        # set to None if info_link (nullable) is None
        # and model_fields_set contains the field
        if self.info_link is None and "info_link" in self.model_fields_set:
            _dict['infoLink'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if presets (nullable) is None
        # and model_fields_set contains the field
        if self.presets is None and "presets" in self.model_fields_set:
            _dict['presets'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetadataResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "fields": [ContractField.from_dict(_item) for _item in obj["fields"]] if obj.get("fields") is not None else None,
            "implementationName": obj.get("implementationName"),
            "implementation": obj.get("implementation"),
            "configContract": obj.get("configContract"),
            "infoLink": obj.get("infoLink"),
            "message": ProviderMessage.from_dict(obj["message"]) if obj.get("message") is not None else None,
            "tags": obj.get("tags"),
            "presets": [MetadataResource.from_dict(_item) for _item in obj["presets"]] if obj.get("presets") is not None else None,
            "enable": obj.get("enable")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
MetadataResource.model_rebuild(raise_errors=False)




# coding: utf-8

# flake8: noqa

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.0" # x-release-please-version

# import apis into sdk package
from whisparr.api.alternative_title_api import AlternativeTitleApi
from whisparr.api.api_info_api import ApiInfoApi
from whisparr.api.authentication_api import AuthenticationApi
from whisparr.api.auto_tagging_api import AutoTaggingApi
from whisparr.api.backup_api import BackupApi
from whisparr.api.blocklist_api import BlocklistApi
from whisparr.api.calendar_api import CalendarApi
from whisparr.api.calendar_feed_api import CalendarFeedApi
from whisparr.api.collection_api import CollectionApi
from whisparr.api.command_api import CommandApi
from whisparr.api.credit_api import CreditApi
from whisparr.api.custom_filter_api import CustomFilterApi
from whisparr.api.custom_format_api import CustomFormatApi
from whisparr.api.delay_profile_api import DelayProfileApi
from whisparr.api.disk_space_api import DiskSpaceApi
from whisparr.api.download_client_api import DownloadClientApi
from whisparr.api.download_client_config_api import DownloadClientConfigApi
from whisparr.api.extra_file_api import ExtraFileApi
from whisparr.api.file_system_api import FileSystemApi
from whisparr.api.health_api import HealthApi
from whisparr.api.history_api import HistoryApi
from whisparr.api.host_config_api import HostConfigApi
from whisparr.api.import_exclusions_api import ImportExclusionsApi
from whisparr.api.import_list_api import ImportListApi
from whisparr.api.import_list_config_api import ImportListConfigApi
from whisparr.api.import_list_movies_api import ImportListMoviesApi
from whisparr.api.indexer_api import IndexerApi
from whisparr.api.indexer_config_api import IndexerConfigApi
from whisparr.api.indexer_flag_api import IndexerFlagApi
from whisparr.api.language_api import LanguageApi
from whisparr.api.localization_api import LocalizationApi
from whisparr.api.log_api import LogApi
from whisparr.api.log_file_api import LogFileApi
from whisparr.api.manual_import_api import ManualImportApi
from whisparr.api.media_cover_api import MediaCoverApi
from whisparr.api.media_management_config_api import MediaManagementConfigApi
from whisparr.api.metadata_api import MetadataApi
from whisparr.api.metadata_config_api import MetadataConfigApi
from whisparr.api.movie_api import MovieApi
from whisparr.api.movie_editor_api import MovieEditorApi
from whisparr.api.movie_file_api import MovieFileApi
from whisparr.api.movie_import_api import MovieImportApi
from whisparr.api.movie_lookup_api import MovieLookupApi
from whisparr.api.naming_config_api import NamingConfigApi
from whisparr.api.notification_api import NotificationApi
from whisparr.api.parse_api import ParseApi
from whisparr.api.ping_api import PingApi
from whisparr.api.quality_definition_api import QualityDefinitionApi
from whisparr.api.quality_profile_api import QualityProfileApi
from whisparr.api.quality_profile_schema_api import QualityProfileSchemaApi
from whisparr.api.queue_api import QueueApi
from whisparr.api.queue_action_api import QueueActionApi
from whisparr.api.queue_details_api import QueueDetailsApi
from whisparr.api.queue_status_api import QueueStatusApi
from whisparr.api.release_api import ReleaseApi
from whisparr.api.release_profile_api import ReleaseProfileApi
from whisparr.api.release_push_api import ReleasePushApi
from whisparr.api.remote_path_mapping_api import RemotePathMappingApi
from whisparr.api.rename_movie_api import RenameMovieApi
from whisparr.api.root_folder_api import RootFolderApi
from whisparr.api.static_resource_api import StaticResourceApi
from whisparr.api.system_api import SystemApi
from whisparr.api.tag_api import TagApi
from whisparr.api.tag_details_api import TagDetailsApi
from whisparr.api.task_api import TaskApi
from whisparr.api.ui_config_api import UiConfigApi
from whisparr.api.update_api import UpdateApi
from whisparr.api.update_log_file_api import UpdateLogFileApi

# import ApiClient
from whisparr.api_response import ApiResponse
from whisparr.api_client import ApiClient
from whisparr.configuration import Configuration
from whisparr.exceptions import OpenApiException
from whisparr.exceptions import ApiTypeError
from whisparr.exceptions import ApiValueError
from whisparr.exceptions import ApiKeyError
from whisparr.exceptions import ApiAttributeError
from whisparr.exceptions import ApiException

# import models into sdk package
from whisparr.models.add_movie_method import AddMovieMethod
from whisparr.models.add_movie_options import AddMovieOptions
from whisparr.models.alternative_title_resource import AlternativeTitleResource
from whisparr.models.api_info_resource import ApiInfoResource
from whisparr.models.apply_tags import ApplyTags
from whisparr.models.authentication_required_type import AuthenticationRequiredType
from whisparr.models.authentication_type import AuthenticationType
from whisparr.models.auto_tagging_resource import AutoTaggingResource
from whisparr.models.auto_tagging_specification_schema import AutoTaggingSpecificationSchema
from whisparr.models.backup_resource import BackupResource
from whisparr.models.backup_type import BackupType
from whisparr.models.blocklist_bulk_resource import BlocklistBulkResource
from whisparr.models.blocklist_resource import BlocklistResource
from whisparr.models.blocklist_resource_paging_resource import BlocklistResourcePagingResource
from whisparr.models.certificate_validation_type import CertificateValidationType
from whisparr.models.collection_movie_resource import CollectionMovieResource
from whisparr.models.collection_resource import CollectionResource
from whisparr.models.collection_update_resource import CollectionUpdateResource
from whisparr.models.colon_replacement_format import ColonReplacementFormat
from whisparr.models.command import Command
from whisparr.models.command_priority import CommandPriority
from whisparr.models.command_resource import CommandResource
from whisparr.models.command_result import CommandResult
from whisparr.models.command_status import CommandStatus
from whisparr.models.command_trigger import CommandTrigger
from whisparr.models.contract_field import ContractField
from whisparr.models.credit_resource import CreditResource
from whisparr.models.credit_type import CreditType
from whisparr.models.custom_filter_resource import CustomFilterResource
from whisparr.models.custom_format_resource import CustomFormatResource
from whisparr.models.custom_format_specification_schema import CustomFormatSpecificationSchema
from whisparr.models.database_type import DatabaseType
from whisparr.models.delay_profile_resource import DelayProfileResource
from whisparr.models.disk_space_resource import DiskSpaceResource
from whisparr.models.download_client_bulk_resource import DownloadClientBulkResource
from whisparr.models.download_client_config_resource import DownloadClientConfigResource
from whisparr.models.download_client_resource import DownloadClientResource
from whisparr.models.download_protocol import DownloadProtocol
from whisparr.models.extra_file_resource import ExtraFileResource
from whisparr.models.extra_file_type import ExtraFileType
from whisparr.models.file_date_type import FileDateType
from whisparr.models.health_check_result import HealthCheckResult
from whisparr.models.health_resource import HealthResource
from whisparr.models.history_resource import HistoryResource
from whisparr.models.history_resource_paging_resource import HistoryResourcePagingResource
from whisparr.models.host_config_resource import HostConfigResource
from whisparr.models.import_exclusions_resource import ImportExclusionsResource
from whisparr.models.import_list_bulk_resource import ImportListBulkResource
from whisparr.models.import_list_config_resource import ImportListConfigResource
from whisparr.models.import_list_resource import ImportListResource
from whisparr.models.import_list_type import ImportListType
from whisparr.models.indexer_bulk_resource import IndexerBulkResource
from whisparr.models.indexer_config_resource import IndexerConfigResource
from whisparr.models.indexer_flag_resource import IndexerFlagResource
from whisparr.models.indexer_resource import IndexerResource
from whisparr.models.language import Language
from whisparr.models.language_resource import LanguageResource
from whisparr.models.localization_language_resource import LocalizationLanguageResource
from whisparr.models.log_file_resource import LogFileResource
from whisparr.models.log_resource import LogResource
from whisparr.models.log_resource_paging_resource import LogResourcePagingResource
from whisparr.models.manual_import_reprocess_resource import ManualImportReprocessResource
from whisparr.models.manual_import_resource import ManualImportResource
from whisparr.models.media_cover import MediaCover
from whisparr.models.media_cover_types import MediaCoverTypes
from whisparr.models.media_info_resource import MediaInfoResource
from whisparr.models.media_management_config_resource import MediaManagementConfigResource
from whisparr.models.metadata_config_resource import MetadataConfigResource
from whisparr.models.metadata_resource import MetadataResource
from whisparr.models.modifier import Modifier
from whisparr.models.monitor_types import MonitorTypes
from whisparr.models.movie_collection_resource import MovieCollectionResource
from whisparr.models.movie_editor_resource import MovieEditorResource
from whisparr.models.movie_file_list_resource import MovieFileListResource
from whisparr.models.movie_file_resource import MovieFileResource
from whisparr.models.movie_history_event_type import MovieHistoryEventType
from whisparr.models.movie_resource import MovieResource
from whisparr.models.movie_runtime_format_type import MovieRuntimeFormatType
from whisparr.models.movie_statistics_resource import MovieStatisticsResource
from whisparr.models.movie_status_type import MovieStatusType
from whisparr.models.naming_config_resource import NamingConfigResource
from whisparr.models.notification_resource import NotificationResource
from whisparr.models.parse_resource import ParseResource
from whisparr.models.parsed_movie_info import ParsedMovieInfo
from whisparr.models.ping_resource import PingResource
from whisparr.models.privacy_level import PrivacyLevel
from whisparr.models.profile_format_item_resource import ProfileFormatItemResource
from whisparr.models.proper_download_types import ProperDownloadTypes
from whisparr.models.provider_message import ProviderMessage
from whisparr.models.provider_message_type import ProviderMessageType
from whisparr.models.proxy_type import ProxyType
from whisparr.models.quality import Quality
from whisparr.models.quality_definition_resource import QualityDefinitionResource
from whisparr.models.quality_model import QualityModel
from whisparr.models.quality_profile_quality_item_resource import QualityProfileQualityItemResource
from whisparr.models.quality_profile_resource import QualityProfileResource
from whisparr.models.quality_source import QualitySource
from whisparr.models.queue_bulk_resource import QueueBulkResource
from whisparr.models.queue_resource import QueueResource
from whisparr.models.queue_resource_paging_resource import QueueResourcePagingResource
from whisparr.models.queue_status_resource import QueueStatusResource
from whisparr.models.rating_child import RatingChild
from whisparr.models.rating_type import RatingType
from whisparr.models.ratings import Ratings
from whisparr.models.rejection import Rejection
from whisparr.models.rejection_type import RejectionType
from whisparr.models.release_profile_resource import ReleaseProfileResource
from whisparr.models.release_resource import ReleaseResource
from whisparr.models.remote_path_mapping_resource import RemotePathMappingResource
from whisparr.models.rename_movie_resource import RenameMovieResource
from whisparr.models.rescan_after_refresh_type import RescanAfterRefreshType
from whisparr.models.revision import Revision
from whisparr.models.root_folder_resource import RootFolderResource
from whisparr.models.runtime_mode import RuntimeMode
from whisparr.models.select_option import SelectOption
from whisparr.models.sort_direction import SortDirection
from whisparr.models.source_type import SourceType
from whisparr.models.system_resource import SystemResource
from whisparr.models.tmdb_country_code import TMDbCountryCode
from whisparr.models.tag_details_resource import TagDetailsResource
from whisparr.models.tag_resource import TagResource
from whisparr.models.task_resource import TaskResource
from whisparr.models.tracked_download_state import TrackedDownloadState
from whisparr.models.tracked_download_status import TrackedDownloadStatus
from whisparr.models.tracked_download_status_message import TrackedDownloadStatusMessage
from whisparr.models.ui_config_resource import UiConfigResource
from whisparr.models.unmapped_folder import UnmappedFolder
from whisparr.models.update_changes import UpdateChanges
from whisparr.models.update_mechanism import UpdateMechanism
from whisparr.models.update_resource import UpdateResource



# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional
from whisparr.models.file_date_type import FileDateType
from whisparr.models.proper_download_types import ProperDownloadTypes
from whisparr.models.rescan_after_refresh_type import RescanAfterRefreshType
from typing import Optional, Set
from typing_extensions import Self

class MediaManagementConfigResource(BaseModel):
    """
    MediaManagementConfigResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    auto_unmonitor_previously_downloaded_movies: Optional[StrictBool] = Field(default=None, alias="autoUnmonitorPreviouslyDownloadedMovies")
    recycle_bin: Optional[StrictStr] = Field(default=None, alias="recycleBin")
    recycle_bin_cleanup_days: Optional[StrictInt] = Field(default=None, alias="recycleBinCleanupDays")
    download_propers_and_repacks: Optional[ProperDownloadTypes] = Field(default=None, alias="downloadPropersAndRepacks")
    create_empty_movie_folders: Optional[StrictBool] = Field(default=None, alias="createEmptyMovieFolders")
    delete_empty_folders: Optional[StrictBool] = Field(default=None, alias="deleteEmptyFolders")
    file_date: Optional[FileDateType] = Field(default=None, alias="fileDate")
    rescan_after_refresh: Optional[RescanAfterRefreshType] = Field(default=None, alias="rescanAfterRefresh")
    auto_rename_folders: Optional[StrictBool] = Field(default=None, alias="autoRenameFolders")
    paths_default_static: Optional[StrictBool] = Field(default=None, alias="pathsDefaultStatic")
    set_permissions_linux: Optional[StrictBool] = Field(default=None, alias="setPermissionsLinux")
    chmod_folder: Optional[StrictStr] = Field(default=None, alias="chmodFolder")
    chown_group: Optional[StrictStr] = Field(default=None, alias="chownGroup")
    skip_free_space_check_when_importing: Optional[StrictBool] = Field(default=None, alias="skipFreeSpaceCheckWhenImporting")
    minimum_free_space_when_importing: Optional[StrictInt] = Field(default=None, alias="minimumFreeSpaceWhenImporting")
    copy_using_hardlinks: Optional[StrictBool] = Field(default=None, alias="copyUsingHardlinks")
    use_script_import: Optional[StrictBool] = Field(default=None, alias="useScriptImport")
    script_import_path: Optional[StrictStr] = Field(default=None, alias="scriptImportPath")
    import_extra_files: Optional[StrictBool] = Field(default=None, alias="importExtraFiles")
    extra_file_extensions: Optional[StrictStr] = Field(default=None, alias="extraFileExtensions")
    enable_media_info: Optional[StrictBool] = Field(default=None, alias="enableMediaInfo")
    __properties: ClassVar[List[str]] = ["id", "autoUnmonitorPreviouslyDownloadedMovies", "recycleBin", "recycleBinCleanupDays", "downloadPropersAndRepacks", "createEmptyMovieFolders", "deleteEmptyFolders", "fileDate", "rescanAfterRefresh", "autoRenameFolders", "pathsDefaultStatic", "setPermissionsLinux", "chmodFolder", "chownGroup", "skipFreeSpaceCheckWhenImporting", "minimumFreeSpaceWhenImporting", "copyUsingHardlinks", "useScriptImport", "scriptImportPath", "importExtraFiles", "extraFileExtensions", "enableMediaInfo"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MediaManagementConfigResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if recycle_bin (nullable) is None
        # and model_fields_set contains the field
        if self.recycle_bin is None and "recycle_bin" in self.model_fields_set:
            _dict['recycleBin'] = None

        # set to None if chmod_folder (nullable) is None
        # and model_fields_set contains the field
        if self.chmod_folder is None and "chmod_folder" in self.model_fields_set:
            _dict['chmodFolder'] = None

        # set to None if chown_group (nullable) is None
        # and model_fields_set contains the field
        if self.chown_group is None and "chown_group" in self.model_fields_set:
            _dict['chownGroup'] = None

        # set to None if script_import_path (nullable) is None
        # and model_fields_set contains the field
        if self.script_import_path is None and "script_import_path" in self.model_fields_set:
            _dict['scriptImportPath'] = None

        # set to None if extra_file_extensions (nullable) is None
        # and model_fields_set contains the field
        if self.extra_file_extensions is None and "extra_file_extensions" in self.model_fields_set:
            _dict['extraFileExtensions'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MediaManagementConfigResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "autoUnmonitorPreviouslyDownloadedMovies": obj.get("autoUnmonitorPreviouslyDownloadedMovies"),
            "recycleBin": obj.get("recycleBin"),
            "recycleBinCleanupDays": obj.get("recycleBinCleanupDays"),
            "downloadPropersAndRepacks": obj.get("downloadPropersAndRepacks"),
            "createEmptyMovieFolders": obj.get("createEmptyMovieFolders"),
            "deleteEmptyFolders": obj.get("deleteEmptyFolders"),
            "fileDate": obj.get("fileDate"),
            "rescanAfterRefresh": obj.get("rescanAfterRefresh"),
            "autoRenameFolders": obj.get("autoRenameFolders"),
            "pathsDefaultStatic": obj.get("pathsDefaultStatic"),
            "setPermissionsLinux": obj.get("setPermissionsLinux"),
            "chmodFolder": obj.get("chmodFolder"),
            "chownGroup": obj.get("chownGroup"),
            "skipFreeSpaceCheckWhenImporting": obj.get("skipFreeSpaceCheckWhenImporting"),
            "minimumFreeSpaceWhenImporting": obj.get("minimumFreeSpaceWhenImporting"),
            "copyUsingHardlinks": obj.get("copyUsingHardlinks"),
            "useScriptImport": obj.get("useScriptImport"),
            "scriptImportPath": obj.get("scriptImportPath"),
            "importExtraFiles": obj.get("importExtraFiles"),
            "extraFileExtensions": obj.get("extraFileExtensions"),
            "enableMediaInfo": obj.get("enableMediaInfo")
        })
        return _obj





# flake8: noqa

# import apis into api package
from whisparr.api.alternative_title_api import AlternativeTitleApi
from whisparr.api.api_info_api import ApiInfoApi
from whisparr.api.authentication_api import AuthenticationApi
from whisparr.api.auto_tagging_api import AutoTaggingApi
from whisparr.api.backup_api import BackupApi
from whisparr.api.blocklist_api import BlocklistApi
from whisparr.api.calendar_api import CalendarApi
from whisparr.api.calendar_feed_api import CalendarFeedApi
from whisparr.api.collection_api import CollectionApi
from whisparr.api.command_api import CommandApi
from whisparr.api.credit_api import CreditApi
from whisparr.api.custom_filter_api import CustomFilterApi
from whisparr.api.custom_format_api import CustomFormatApi
from whisparr.api.delay_profile_api import DelayProfileApi
from whisparr.api.disk_space_api import DiskSpaceApi
from whisparr.api.download_client_api import DownloadClientApi
from whisparr.api.download_client_config_api import DownloadClientConfigApi
from whisparr.api.extra_file_api import ExtraFileApi
from whisparr.api.file_system_api import FileSystemApi
from whisparr.api.health_api import HealthApi
from whisparr.api.history_api import HistoryApi
from whisparr.api.host_config_api import HostConfigApi
from whisparr.api.import_exclusions_api import ImportExclusionsApi
from whisparr.api.import_list_api import ImportListApi
from whisparr.api.import_list_config_api import ImportListConfigApi
from whisparr.api.import_list_movies_api import ImportListMoviesApi
from whisparr.api.indexer_api import IndexerApi
from whisparr.api.indexer_config_api import IndexerConfigApi
from whisparr.api.indexer_flag_api import IndexerFlagApi
from whisparr.api.language_api import LanguageApi
from whisparr.api.localization_api import LocalizationApi
from whisparr.api.log_api import LogApi
from whisparr.api.log_file_api import LogFileApi
from whisparr.api.manual_import_api import ManualImportApi
from whisparr.api.media_cover_api import MediaCoverApi
from whisparr.api.media_management_config_api import MediaManagementConfigApi
from whisparr.api.metadata_api import MetadataApi
from whisparr.api.metadata_config_api import MetadataConfigApi
from whisparr.api.movie_api import MovieApi
from whisparr.api.movie_editor_api import MovieEditorApi
from whisparr.api.movie_file_api import MovieFileApi
from whisparr.api.movie_import_api import MovieImportApi
from whisparr.api.movie_lookup_api import MovieLookupApi
from whisparr.api.naming_config_api import NamingConfigApi
from whisparr.api.notification_api import NotificationApi
from whisparr.api.parse_api import ParseApi
from whisparr.api.ping_api import PingApi
from whisparr.api.quality_definition_api import QualityDefinitionApi
from whisparr.api.quality_profile_api import QualityProfileApi
from whisparr.api.quality_profile_schema_api import QualityProfileSchemaApi
from whisparr.api.queue_api import QueueApi
from whisparr.api.queue_action_api import QueueActionApi
from whisparr.api.queue_details_api import QueueDetailsApi
from whisparr.api.queue_status_api import QueueStatusApi
from whisparr.api.release_api import ReleaseApi
from whisparr.api.release_profile_api import ReleaseProfileApi
from whisparr.api.release_push_api import ReleasePushApi
from whisparr.api.remote_path_mapping_api import RemotePathMappingApi
from whisparr.api.rename_movie_api import RenameMovieApi
from whisparr.api.root_folder_api import RootFolderApi
from whisparr.api.static_resource_api import StaticResourceApi
from whisparr.api.system_api import SystemApi
from whisparr.api.tag_api import TagApi
from whisparr.api.tag_details_api import TagDetailsApi
from whisparr.api.task_api import TaskApi
from whisparr.api.ui_config_api import UiConfigApi
from whisparr.api.update_api import UpdateApi
from whisparr.api.update_log_file_api import UpdateLogFileApi




# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from whisparr.models.custom_format_resource import CustomFormatResource
from whisparr.models.download_protocol import DownloadProtocol
from whisparr.models.language import Language
from whisparr.models.movie_resource import MovieResource
from whisparr.models.quality_model import QualityModel
from whisparr.models.tracked_download_state import TrackedDownloadState
from whisparr.models.tracked_download_status import TrackedDownloadStatus
from whisparr.models.tracked_download_status_message import TrackedDownloadStatusMessage
from typing import Optional, Set
from typing_extensions import Self

class QueueResource(BaseModel):
    """
    QueueResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    movie_id: Optional[StrictInt] = Field(default=None, alias="movieId")
    movie: Optional[MovieResource] = None
    languages: Optional[List[Language]] = None
    quality: Optional[QualityModel] = None
    custom_formats: Optional[List[CustomFormatResource]] = Field(default=None, alias="customFormats")
    custom_format_score: Optional[StrictInt] = Field(default=None, alias="customFormatScore")
    size: Optional[Union[StrictFloat, StrictInt]] = None
    title: Optional[StrictStr] = None
    sizeleft: Optional[Union[StrictFloat, StrictInt]] = None
    timeleft: Optional[StrictStr] = None
    estimated_completion_time: Optional[datetime] = Field(default=None, alias="estimatedCompletionTime")
    added: Optional[datetime] = None
    status: Optional[StrictStr] = None
    tracked_download_status: Optional[TrackedDownloadStatus] = Field(default=None, alias="trackedDownloadStatus")
    tracked_download_state: Optional[TrackedDownloadState] = Field(default=None, alias="trackedDownloadState")
    status_messages: Optional[List[TrackedDownloadStatusMessage]] = Field(default=None, alias="statusMessages")
    error_message: Optional[StrictStr] = Field(default=None, alias="errorMessage")
    download_id: Optional[StrictStr] = Field(default=None, alias="downloadId")
    protocol: Optional[DownloadProtocol] = None
    download_client: Optional[StrictStr] = Field(default=None, alias="downloadClient")
    download_client_has_post_import_category: Optional[StrictBool] = Field(default=None, alias="downloadClientHasPostImportCategory")
    indexer: Optional[StrictStr] = None
    output_path: Optional[StrictStr] = Field(default=None, alias="outputPath")
    __properties: ClassVar[List[str]] = ["id", "movieId", "movie", "languages", "quality", "customFormats", "customFormatScore", "size", "title", "sizeleft", "timeleft", "estimatedCompletionTime", "added", "status", "trackedDownloadStatus", "trackedDownloadState", "statusMessages", "errorMessage", "downloadId", "protocol", "downloadClient", "downloadClientHasPostImportCategory", "indexer", "outputPath"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QueueResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of movie
        if self.movie:
            _dict['movie'] = self.movie.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item_languages in self.languages:
                if _item_languages:
                    _items.append(_item_languages.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in custom_formats (list)
        _items = []
        if self.custom_formats:
            for _item_custom_formats in self.custom_formats:
                if _item_custom_formats:
                    _items.append(_item_custom_formats.to_dict())
            _dict['customFormats'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in status_messages (list)
        _items = []
        if self.status_messages:
            for _item_status_messages in self.status_messages:
                if _item_status_messages:
                    _items.append(_item_status_messages.to_dict())
            _dict['statusMessages'] = _items
        # set to None if movie_id (nullable) is None
        # and model_fields_set contains the field
        if self.movie_id is None and "movie_id" in self.model_fields_set:
            _dict['movieId'] = None

        # set to None if languages (nullable) is None
        # and model_fields_set contains the field
        if self.languages is None and "languages" in self.model_fields_set:
            _dict['languages'] = None

        # set to None if custom_formats (nullable) is None
        # and model_fields_set contains the field
        if self.custom_formats is None and "custom_formats" in self.model_fields_set:
            _dict['customFormats'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if estimated_completion_time (nullable) is None
        # and model_fields_set contains the field
        if self.estimated_completion_time is None and "estimated_completion_time" in self.model_fields_set:
            _dict['estimatedCompletionTime'] = None

        # set to None if added (nullable) is None
        # and model_fields_set contains the field
        if self.added is None and "added" in self.model_fields_set:
            _dict['added'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if status_messages (nullable) is None
        # and model_fields_set contains the field
        if self.status_messages is None and "status_messages" in self.model_fields_set:
            _dict['statusMessages'] = None

        # set to None if error_message (nullable) is None
        # and model_fields_set contains the field
        if self.error_message is None and "error_message" in self.model_fields_set:
            _dict['errorMessage'] = None

        # set to None if download_id (nullable) is None
        # and model_fields_set contains the field
        if self.download_id is None and "download_id" in self.model_fields_set:
            _dict['downloadId'] = None

        # set to None if download_client (nullable) is None
        # and model_fields_set contains the field
        if self.download_client is None and "download_client" in self.model_fields_set:
            _dict['downloadClient'] = None

        # set to None if indexer (nullable) is None
        # and model_fields_set contains the field
        if self.indexer is None and "indexer" in self.model_fields_set:
            _dict['indexer'] = None

        # set to None if output_path (nullable) is None
        # and model_fields_set contains the field
        if self.output_path is None and "output_path" in self.model_fields_set:
            _dict['outputPath'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QueueResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "movieId": obj.get("movieId"),
            "movie": MovieResource.from_dict(obj["movie"]) if obj.get("movie") is not None else None,
            "languages": [Language.from_dict(_item) for _item in obj["languages"]] if obj.get("languages") is not None else None,
            "quality": QualityModel.from_dict(obj["quality"]) if obj.get("quality") is not None else None,
            "customFormats": [CustomFormatResource.from_dict(_item) for _item in obj["customFormats"]] if obj.get("customFormats") is not None else None,
            "customFormatScore": obj.get("customFormatScore"),
            "size": obj.get("size"),
            "title": obj.get("title"),
            "sizeleft": obj.get("sizeleft"),
            "timeleft": obj.get("timeleft"),
            "estimatedCompletionTime": obj.get("estimatedCompletionTime"),
            "added": obj.get("added"),
            "status": obj.get("status"),
            "trackedDownloadStatus": obj.get("trackedDownloadStatus"),
            "trackedDownloadState": obj.get("trackedDownloadState"),
            "statusMessages": [TrackedDownloadStatusMessage.from_dict(_item) for _item in obj["statusMessages"]] if obj.get("statusMessages") is not None else None,
            "errorMessage": obj.get("errorMessage"),
            "downloadId": obj.get("downloadId"),
            "protocol": obj.get("protocol"),
            "downloadClient": obj.get("downloadClient"),
            "downloadClientHasPostImportCategory": obj.get("downloadClientHasPostImportCategory"),
            "indexer": obj.get("indexer"),
            "outputPath": obj.get("outputPath")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from whisparr.models.add_movie_options import AddMovieOptions
from whisparr.models.alternative_title_resource import AlternativeTitleResource
from whisparr.models.language import Language
from whisparr.models.media_cover import MediaCover
from whisparr.models.movie_collection_resource import MovieCollectionResource
from whisparr.models.movie_file_resource import MovieFileResource
from whisparr.models.movie_statistics_resource import MovieStatisticsResource
from whisparr.models.movie_status_type import MovieStatusType
from whisparr.models.ratings import Ratings
from typing import Optional, Set
from typing_extensions import Self

class MovieResource(BaseModel):
    """
    MovieResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    title: Optional[StrictStr] = None
    original_title: Optional[StrictStr] = Field(default=None, alias="originalTitle")
    original_language: Optional[Language] = Field(default=None, alias="originalLanguage")
    alternate_titles: Optional[List[AlternativeTitleResource]] = Field(default=None, alias="alternateTitles")
    secondary_year: Optional[StrictInt] = Field(default=None, alias="secondaryYear")
    secondary_year_source_id: Optional[StrictInt] = Field(default=None, alias="secondaryYearSourceId")
    sort_title: Optional[StrictStr] = Field(default=None, alias="sortTitle")
    size_on_disk: Optional[StrictInt] = Field(default=None, alias="sizeOnDisk")
    status: Optional[MovieStatusType] = None
    overview: Optional[StrictStr] = None
    in_cinemas: Optional[datetime] = Field(default=None, alias="inCinemas")
    physical_release: Optional[datetime] = Field(default=None, alias="physicalRelease")
    digital_release: Optional[datetime] = Field(default=None, alias="digitalRelease")
    physical_release_note: Optional[StrictStr] = Field(default=None, alias="physicalReleaseNote")
    images: Optional[List[MediaCover]] = None
    website: Optional[StrictStr] = None
    remote_poster: Optional[StrictStr] = Field(default=None, alias="remotePoster")
    year: Optional[StrictInt] = None
    you_tube_trailer_id: Optional[StrictStr] = Field(default=None, alias="youTubeTrailerId")
    studio: Optional[StrictStr] = None
    path: Optional[StrictStr] = None
    quality_profile_id: Optional[StrictInt] = Field(default=None, alias="qualityProfileId")
    has_file: Optional[StrictBool] = Field(default=None, alias="hasFile")
    monitored: Optional[StrictBool] = None
    minimum_availability: Optional[MovieStatusType] = Field(default=None, alias="minimumAvailability")
    is_available: Optional[StrictBool] = Field(default=None, alias="isAvailable")
    folder_name: Optional[StrictStr] = Field(default=None, alias="folderName")
    runtime: Optional[StrictInt] = None
    clean_title: Optional[StrictStr] = Field(default=None, alias="cleanTitle")
    imdb_id: Optional[StrictStr] = Field(default=None, alias="imdbId")
    tmdb_id: Optional[StrictInt] = Field(default=None, alias="tmdbId")
    title_slug: Optional[StrictStr] = Field(default=None, alias="titleSlug")
    root_folder_path: Optional[StrictStr] = Field(default=None, alias="rootFolderPath")
    folder: Optional[StrictStr] = None
    certification: Optional[StrictStr] = None
    genres: Optional[List[StrictStr]] = None
    tags: Optional[List[StrictInt]] = None
    added: Optional[datetime] = None
    add_options: Optional[AddMovieOptions] = Field(default=None, alias="addOptions")
    ratings: Optional[Ratings] = None
    movie_file: Optional[MovieFileResource] = Field(default=None, alias="movieFile")
    collection: Optional[MovieCollectionResource] = None
    popularity: Optional[Union[StrictFloat, StrictInt]] = None
    statistics: Optional[MovieStatisticsResource] = None
    __properties: ClassVar[List[str]] = ["id", "title", "originalTitle", "originalLanguage", "alternateTitles", "secondaryYear", "secondaryYearSourceId", "sortTitle", "sizeOnDisk", "status", "overview", "inCinemas", "physicalRelease", "digitalRelease", "physicalReleaseNote", "images", "website", "remotePoster", "year", "youTubeTrailerId", "studio", "path", "qualityProfileId", "hasFile", "monitored", "minimumAvailability", "isAvailable", "folderName", "runtime", "cleanTitle", "imdbId", "tmdbId", "titleSlug", "rootFolderPath", "folder", "certification", "genres", "tags", "added", "addOptions", "ratings", "movieFile", "collection", "popularity", "statistics"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MovieResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of original_language
        if self.original_language:
            _dict['originalLanguage'] = self.original_language.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in alternate_titles (list)
        _items = []
        if self.alternate_titles:
            for _item_alternate_titles in self.alternate_titles:
                if _item_alternate_titles:
                    _items.append(_item_alternate_titles.to_dict())
            _dict['alternateTitles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item_images in self.images:
                if _item_images:
                    _items.append(_item_images.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of add_options
        if self.add_options:
            _dict['addOptions'] = self.add_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ratings
        if self.ratings:
            _dict['ratings'] = self.ratings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of movie_file
        if self.movie_file:
            _dict['movieFile'] = self.movie_file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of collection
        if self.collection:
            _dict['collection'] = self.collection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of statistics
        if self.statistics:
            _dict['statistics'] = self.statistics.to_dict()
        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if original_title (nullable) is None
        # and model_fields_set contains the field
        if self.original_title is None and "original_title" in self.model_fields_set:
            _dict['originalTitle'] = None

        # set to None if alternate_titles (nullable) is None
        # and model_fields_set contains the field
        if self.alternate_titles is None and "alternate_titles" in self.model_fields_set:
            _dict['alternateTitles'] = None

        # set to None if secondary_year (nullable) is None
        # and model_fields_set contains the field
        if self.secondary_year is None and "secondary_year" in self.model_fields_set:
            _dict['secondaryYear'] = None

        # set to None if sort_title (nullable) is None
        # and model_fields_set contains the field
        if self.sort_title is None and "sort_title" in self.model_fields_set:
            _dict['sortTitle'] = None

        # set to None if size_on_disk (nullable) is None
        # and model_fields_set contains the field
        if self.size_on_disk is None and "size_on_disk" in self.model_fields_set:
            _dict['sizeOnDisk'] = None

        # set to None if overview (nullable) is None
        # and model_fields_set contains the field
        if self.overview is None and "overview" in self.model_fields_set:
            _dict['overview'] = None

        # set to None if in_cinemas (nullable) is None
        # and model_fields_set contains the field
        if self.in_cinemas is None and "in_cinemas" in self.model_fields_set:
            _dict['inCinemas'] = None

        # set to None if physical_release (nullable) is None
        # and model_fields_set contains the field
        if self.physical_release is None and "physical_release" in self.model_fields_set:
            _dict['physicalRelease'] = None

        # set to None if digital_release (nullable) is None
        # and model_fields_set contains the field
        if self.digital_release is None and "digital_release" in self.model_fields_set:
            _dict['digitalRelease'] = None

        # set to None if physical_release_note (nullable) is None
        # and model_fields_set contains the field
        if self.physical_release_note is None and "physical_release_note" in self.model_fields_set:
            _dict['physicalReleaseNote'] = None

        # set to None if images (nullable) is None
        # and model_fields_set contains the field
        if self.images is None and "images" in self.model_fields_set:
            _dict['images'] = None

        # set to None if website (nullable) is None
        # and model_fields_set contains the field
        if self.website is None and "website" in self.model_fields_set:
            _dict['website'] = None

        # set to None if remote_poster (nullable) is None
        # and model_fields_set contains the field
        if self.remote_poster is None and "remote_poster" in self.model_fields_set:
            _dict['remotePoster'] = None

        # set to None if you_tube_trailer_id (nullable) is None
        # and model_fields_set contains the field
        if self.you_tube_trailer_id is None and "you_tube_trailer_id" in self.model_fields_set:
            _dict['youTubeTrailerId'] = None

        # set to None if studio (nullable) is None
        # and model_fields_set contains the field
        if self.studio is None and "studio" in self.model_fields_set:
            _dict['studio'] = None

        # set to None if path (nullable) is None
        # and model_fields_set contains the field
        if self.path is None and "path" in self.model_fields_set:
            _dict['path'] = None

        # set to None if has_file (nullable) is None
        # and model_fields_set contains the field
        if self.has_file is None and "has_file" in self.model_fields_set:
            _dict['hasFile'] = None

        # set to None if folder_name (nullable) is None
        # and model_fields_set contains the field
        if self.folder_name is None and "folder_name" in self.model_fields_set:
            _dict['folderName'] = None

        # set to None if clean_title (nullable) is None
        # and model_fields_set contains the field
        if self.clean_title is None and "clean_title" in self.model_fields_set:
            _dict['cleanTitle'] = None

        # set to None if imdb_id (nullable) is None
        # and model_fields_set contains the field
        if self.imdb_id is None and "imdb_id" in self.model_fields_set:
            _dict['imdbId'] = None

        # set to None if title_slug (nullable) is None
        # and model_fields_set contains the field
        if self.title_slug is None and "title_slug" in self.model_fields_set:
            _dict['titleSlug'] = None

        # set to None if root_folder_path (nullable) is None
        # and model_fields_set contains the field
        if self.root_folder_path is None and "root_folder_path" in self.model_fields_set:
            _dict['rootFolderPath'] = None

        # set to None if folder (nullable) is None
        # and model_fields_set contains the field
        if self.folder is None and "folder" in self.model_fields_set:
            _dict['folder'] = None

        # set to None if certification (nullable) is None
        # and model_fields_set contains the field
        if self.certification is None and "certification" in self.model_fields_set:
            _dict['certification'] = None

        # set to None if genres (nullable) is None
        # and model_fields_set contains the field
        if self.genres is None and "genres" in self.model_fields_set:
            _dict['genres'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MovieResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "originalTitle": obj.get("originalTitle"),
            "originalLanguage": Language.from_dict(obj["originalLanguage"]) if obj.get("originalLanguage") is not None else None,
            "alternateTitles": [AlternativeTitleResource.from_dict(_item) for _item in obj["alternateTitles"]] if obj.get("alternateTitles") is not None else None,
            "secondaryYear": obj.get("secondaryYear"),
            "secondaryYearSourceId": obj.get("secondaryYearSourceId"),
            "sortTitle": obj.get("sortTitle"),
            "sizeOnDisk": obj.get("sizeOnDisk"),
            "status": obj.get("status"),
            "overview": obj.get("overview"),
            "inCinemas": obj.get("inCinemas"),
            "physicalRelease": obj.get("physicalRelease"),
            "digitalRelease": obj.get("digitalRelease"),
            "physicalReleaseNote": obj.get("physicalReleaseNote"),
            "images": [MediaCover.from_dict(_item) for _item in obj["images"]] if obj.get("images") is not None else None,
            "website": obj.get("website"),
            "remotePoster": obj.get("remotePoster"),
            "year": obj.get("year"),
            "youTubeTrailerId": obj.get("youTubeTrailerId"),
            "studio": obj.get("studio"),
            "path": obj.get("path"),
            "qualityProfileId": obj.get("qualityProfileId"),
            "hasFile": obj.get("hasFile"),
            "monitored": obj.get("monitored"),
            "minimumAvailability": obj.get("minimumAvailability"),
            "isAvailable": obj.get("isAvailable"),
            "folderName": obj.get("folderName"),
            "runtime": obj.get("runtime"),
            "cleanTitle": obj.get("cleanTitle"),
            "imdbId": obj.get("imdbId"),
            "tmdbId": obj.get("tmdbId"),
            "titleSlug": obj.get("titleSlug"),
            "rootFolderPath": obj.get("rootFolderPath"),
            "folder": obj.get("folder"),
            "certification": obj.get("certification"),
            "genres": obj.get("genres"),
            "tags": obj.get("tags"),
            "added": obj.get("added"),
            "addOptions": AddMovieOptions.from_dict(obj["addOptions"]) if obj.get("addOptions") is not None else None,
            "ratings": Ratings.from_dict(obj["ratings"]) if obj.get("ratings") is not None else None,
            "movieFile": MovieFileResource.from_dict(obj["movieFile"]) if obj.get("movieFile") is not None else None,
            "collection": MovieCollectionResource.from_dict(obj["collection"]) if obj.get("collection") is not None else None,
            "popularity": obj.get("popularity"),
            "statistics": MovieStatisticsResource.from_dict(obj["statistics"]) if obj.get("statistics") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.custom_format_resource import CustomFormatResource
from whisparr.models.language import Language
from whisparr.models.movie_resource import MovieResource
from whisparr.models.parsed_movie_info import ParsedMovieInfo
from typing import Optional, Set
from typing_extensions import Self

class ParseResource(BaseModel):
    """
    ParseResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    title: Optional[StrictStr] = None
    parsed_movie_info: Optional[ParsedMovieInfo] = Field(default=None, alias="parsedMovieInfo")
    movie: Optional[MovieResource] = None
    languages: Optional[List[Language]] = None
    custom_formats: Optional[List[CustomFormatResource]] = Field(default=None, alias="customFormats")
    custom_format_score: Optional[StrictInt] = Field(default=None, alias="customFormatScore")
    __properties: ClassVar[List[str]] = ["id", "title", "parsedMovieInfo", "movie", "languages", "customFormats", "customFormatScore"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ParseResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of parsed_movie_info
        if self.parsed_movie_info:
            _dict['parsedMovieInfo'] = self.parsed_movie_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of movie
        if self.movie:
            _dict['movie'] = self.movie.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in languages (list)
        _items = []
        if self.languages:
            for _item_languages in self.languages:
                if _item_languages:
                    _items.append(_item_languages.to_dict())
            _dict['languages'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in custom_formats (list)
        _items = []
        if self.custom_formats:
            for _item_custom_formats in self.custom_formats:
                if _item_custom_formats:
                    _items.append(_item_custom_formats.to_dict())
            _dict['customFormats'] = _items
        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if languages (nullable) is None
        # and model_fields_set contains the field
        if self.languages is None and "languages" in self.model_fields_set:
            _dict['languages'] = None

        # set to None if custom_formats (nullable) is None
        # and model_fields_set contains the field
        if self.custom_formats is None and "custom_formats" in self.model_fields_set:
            _dict['customFormats'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ParseResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "parsedMovieInfo": ParsedMovieInfo.from_dict(obj["parsedMovieInfo"]) if obj.get("parsedMovieInfo") is not None else None,
            "movie": MovieResource.from_dict(obj["movie"]) if obj.get("movie") is not None else None,
            "languages": [Language.from_dict(_item) for _item in obj["languages"]] if obj.get("languages") is not None else None,
            "customFormats": [CustomFormatResource.from_dict(_item) for _item in obj["customFormats"]] if obj.get("customFormats") is not None else None,
            "customFormatScore": obj.get("customFormatScore")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MediaCoverTypes(str, Enum):
    """
    MediaCoverTypes
    """

    """
    allowed enum values
    """
    UNKNOWN = 'unknown'
    POSTER = 'poster'
    BANNER = 'banner'
    FANART = 'fanart'
    SCREENSHOT = 'screenshot'
    HEADSHOT = 'headshot'
    CLEARLOGO = 'clearlogo'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MediaCoverTypes from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.collection_movie_resource import CollectionMovieResource
from whisparr.models.media_cover import MediaCover
from whisparr.models.movie_status_type import MovieStatusType
from typing import Optional, Set
from typing_extensions import Self

class CollectionResource(BaseModel):
    """
    CollectionResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    title: Optional[StrictStr] = None
    sort_title: Optional[StrictStr] = Field(default=None, alias="sortTitle")
    tmdb_id: Optional[StrictInt] = Field(default=None, alias="tmdbId")
    images: Optional[List[MediaCover]] = None
    overview: Optional[StrictStr] = None
    monitored: Optional[StrictBool] = None
    root_folder_path: Optional[StrictStr] = Field(default=None, alias="rootFolderPath")
    quality_profile_id: Optional[StrictInt] = Field(default=None, alias="qualityProfileId")
    search_on_add: Optional[StrictBool] = Field(default=None, alias="searchOnAdd")
    minimum_availability: Optional[MovieStatusType] = Field(default=None, alias="minimumAvailability")
    movies: Optional[List[CollectionMovieResource]] = None
    missing_movies: Optional[StrictInt] = Field(default=None, alias="missingMovies")
    tags: Optional[List[StrictInt]] = None
    __properties: ClassVar[List[str]] = ["id", "title", "sortTitle", "tmdbId", "images", "overview", "monitored", "rootFolderPath", "qualityProfileId", "searchOnAdd", "minimumAvailability", "movies", "missingMovies", "tags"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CollectionResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item_images in self.images:
                if _item_images:
                    _items.append(_item_images.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in movies (list)
        _items = []
        if self.movies:
            for _item_movies in self.movies:
                if _item_movies:
                    _items.append(_item_movies.to_dict())
            _dict['movies'] = _items
        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if sort_title (nullable) is None
        # and model_fields_set contains the field
        if self.sort_title is None and "sort_title" in self.model_fields_set:
            _dict['sortTitle'] = None

        # set to None if images (nullable) is None
        # and model_fields_set contains the field
        if self.images is None and "images" in self.model_fields_set:
            _dict['images'] = None

        # set to None if overview (nullable) is None
        # and model_fields_set contains the field
        if self.overview is None and "overview" in self.model_fields_set:
            _dict['overview'] = None

        # set to None if root_folder_path (nullable) is None
        # and model_fields_set contains the field
        if self.root_folder_path is None and "root_folder_path" in self.model_fields_set:
            _dict['rootFolderPath'] = None

        # set to None if movies (nullable) is None
        # and model_fields_set contains the field
        if self.movies is None and "movies" in self.model_fields_set:
            _dict['movies'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CollectionResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "title": obj.get("title"),
            "sortTitle": obj.get("sortTitle"),
            "tmdbId": obj.get("tmdbId"),
            "images": [MediaCover.from_dict(_item) for _item in obj["images"]] if obj.get("images") is not None else None,
            "overview": obj.get("overview"),
            "monitored": obj.get("monitored"),
            "rootFolderPath": obj.get("rootFolderPath"),
            "qualityProfileId": obj.get("qualityProfileId"),
            "searchOnAdd": obj.get("searchOnAdd"),
            "minimumAvailability": obj.get("minimumAvailability"),
            "movies": [CollectionMovieResource.from_dict(_item) for _item in obj["movies"]] if obj.get("movies") is not None else None,
            "missingMovies": obj.get("missingMovies"),
            "tags": obj.get("tags")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.log_resource import LogResource
from whisparr.models.sort_direction import SortDirection
from typing import Optional, Set
from typing_extensions import Self

class LogResourcePagingResource(BaseModel):
    """
    LogResourcePagingResource
    """ # noqa: E501
    page: Optional[StrictInt] = None
    page_size: Optional[StrictInt] = Field(default=None, alias="pageSize")
    sort_key: Optional[StrictStr] = Field(default=None, alias="sortKey")
    sort_direction: Optional[SortDirection] = Field(default=None, alias="sortDirection")
    total_records: Optional[StrictInt] = Field(default=None, alias="totalRecords")
    records: Optional[List[LogResource]] = None
    __properties: ClassVar[List[str]] = ["page", "pageSize", "sortKey", "sortDirection", "totalRecords", "records"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LogResourcePagingResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in records (list)
        _items = []
        if self.records:
            for _item_records in self.records:
                if _item_records:
                    _items.append(_item_records.to_dict())
            _dict['records'] = _items
        # set to None if sort_key (nullable) is None
        # and model_fields_set contains the field
        if self.sort_key is None and "sort_key" in self.model_fields_set:
            _dict['sortKey'] = None

        # set to None if records (nullable) is None
        # and model_fields_set contains the field
        if self.records is None and "records" in self.model_fields_set:
            _dict['records'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LogResourcePagingResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "page": obj.get("page"),
            "pageSize": obj.get("pageSize"),
            "sortKey": obj.get("sortKey"),
            "sortDirection": obj.get("sortDirection"),
            "totalRecords": obj.get("totalRecords"),
            "records": [LogResource.from_dict(_item) for _item in obj["records"]] if obj.get("records") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TMDbCountryCode(str, Enum):
    """
    TMDbCountryCode
    """

    """
    allowed enum values
    """
    AU = 'au'
    BR = 'br'
    CA = 'ca'
    FR = 'fr'
    DE = 'de'
    GB = 'gb'
    IE = 'ie'
    IT = 'it'
    ES = 'es'
    US = 'us'
    NZ = 'nz'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TMDbCountryCode from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional, Union
from whisparr.models.quality import Quality
from typing import Optional, Set
from typing_extensions import Self

class QualityDefinitionResource(BaseModel):
    """
    QualityDefinitionResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    quality: Optional[Quality] = None
    title: Optional[StrictStr] = None
    weight: Optional[StrictInt] = None
    min_size: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="minSize")
    max_size: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxSize")
    preferred_size: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="preferredSize")
    __properties: ClassVar[List[str]] = ["id", "quality", "title", "weight", "minSize", "maxSize", "preferredSize"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of QualityDefinitionResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of quality
        if self.quality:
            _dict['quality'] = self.quality.to_dict()
        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if min_size (nullable) is None
        # and model_fields_set contains the field
        if self.min_size is None and "min_size" in self.model_fields_set:
            _dict['minSize'] = None

        # set to None if max_size (nullable) is None
        # and model_fields_set contains the field
        if self.max_size is None and "max_size" in self.model_fields_set:
            _dict['maxSize'] = None

        # set to None if preferred_size (nullable) is None
        # and model_fields_set contains the field
        if self.preferred_size is None and "preferred_size" in self.model_fields_set:
            _dict['preferredSize'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of QualityDefinitionResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "quality": Quality.from_dict(obj["quality"]) if obj.get("quality") is not None else None,
            "title": obj.get("title"),
            "weight": obj.get("weight"),
            "minSize": obj.get("minSize"),
            "maxSize": obj.get("maxSize"),
            "preferredSize": obj.get("preferredSize")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, Optional
from whisparr.models.command_trigger import CommandTrigger
from typing import Optional, Set
from typing_extensions import Self

class Command(BaseModel):
    """
    Command
    """ # noqa: E501
    send_updates_to_client: Optional[StrictBool] = Field(default=None, alias="sendUpdatesToClient")
    update_scheduled_task: Optional[StrictBool] = Field(default=None, alias="updateScheduledTask")
    completion_message: Optional[StrictStr] = Field(default=None, alias="completionMessage")
    requires_disk_access: Optional[StrictBool] = Field(default=None, alias="requiresDiskAccess")
    is_exclusive: Optional[StrictBool] = Field(default=None, alias="isExclusive")
    is_type_exclusive: Optional[StrictBool] = Field(default=None, alias="isTypeExclusive")
    is_long_running: Optional[StrictBool] = Field(default=None, alias="isLongRunning")
    name: Optional[StrictStr] = None
    last_execution_time: Optional[datetime] = Field(default=None, alias="lastExecutionTime")
    last_start_time: Optional[datetime] = Field(default=None, alias="lastStartTime")
    trigger: Optional[CommandTrigger] = None
    suppress_messages: Optional[StrictBool] = Field(default=None, alias="suppressMessages")
    client_user_agent: Optional[StrictStr] = Field(default=None, alias="clientUserAgent")
    __properties: ClassVar[List[str]] = ["sendUpdatesToClient", "updateScheduledTask", "completionMessage", "requiresDiskAccess", "isExclusive", "isTypeExclusive", "isLongRunning", "name", "lastExecutionTime", "lastStartTime", "trigger", "suppressMessages", "clientUserAgent"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Command from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "update_scheduled_task",
            "completion_message",
            "requires_disk_access",
            "is_exclusive",
            "is_type_exclusive",
            "is_long_running",
            "name",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if completion_message (nullable) is None
        # and model_fields_set contains the field
        if self.completion_message is None and "completion_message" in self.model_fields_set:
            _dict['completionMessage'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if last_execution_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_execution_time is None and "last_execution_time" in self.model_fields_set:
            _dict['lastExecutionTime'] = None

        # set to None if last_start_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_start_time is None and "last_start_time" in self.model_fields_set:
            _dict['lastStartTime'] = None

        # set to None if client_user_agent (nullable) is None
        # and model_fields_set contains the field
        if self.client_user_agent is None and "client_user_agent" in self.model_fields_set:
            _dict['clientUserAgent'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Command from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "sendUpdatesToClient": obj.get("sendUpdatesToClient"),
            "updateScheduledTask": obj.get("updateScheduledTask"),
            "completionMessage": obj.get("completionMessage"),
            "requiresDiskAccess": obj.get("requiresDiskAccess"),
            "isExclusive": obj.get("isExclusive"),
            "isTypeExclusive": obj.get("isTypeExclusive"),
            "isLongRunning": obj.get("isLongRunning"),
            "name": obj.get("name"),
            "lastExecutionTime": obj.get("lastExecutionTime"),
            "lastStartTime": obj.get("lastStartTime"),
            "trigger": obj.get("trigger"),
            "suppressMessages": obj.get("suppressMessages"),
            "clientUserAgent": obj.get("clientUserAgent")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class MediaInfoResource(BaseModel):
    """
    MediaInfoResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    audio_bitrate: Optional[StrictInt] = Field(default=None, alias="audioBitrate")
    audio_channels: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="audioChannels")
    audio_codec: Optional[StrictStr] = Field(default=None, alias="audioCodec")
    audio_languages: Optional[StrictStr] = Field(default=None, alias="audioLanguages")
    audio_stream_count: Optional[StrictInt] = Field(default=None, alias="audioStreamCount")
    video_bit_depth: Optional[StrictInt] = Field(default=None, alias="videoBitDepth")
    video_bitrate: Optional[StrictInt] = Field(default=None, alias="videoBitrate")
    video_codec: Optional[StrictStr] = Field(default=None, alias="videoCodec")
    video_fps: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="videoFps")
    video_dynamic_range: Optional[StrictStr] = Field(default=None, alias="videoDynamicRange")
    video_dynamic_range_type: Optional[StrictStr] = Field(default=None, alias="videoDynamicRangeType")
    resolution: Optional[StrictStr] = None
    run_time: Optional[StrictStr] = Field(default=None, alias="runTime")
    scan_type: Optional[StrictStr] = Field(default=None, alias="scanType")
    subtitles: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["id", "audioBitrate", "audioChannels", "audioCodec", "audioLanguages", "audioStreamCount", "videoBitDepth", "videoBitrate", "videoCodec", "videoFps", "videoDynamicRange", "videoDynamicRangeType", "resolution", "runTime", "scanType", "subtitles"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MediaInfoResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if audio_codec (nullable) is None
        # and model_fields_set contains the field
        if self.audio_codec is None and "audio_codec" in self.model_fields_set:
            _dict['audioCodec'] = None

        # set to None if audio_languages (nullable) is None
        # and model_fields_set contains the field
        if self.audio_languages is None and "audio_languages" in self.model_fields_set:
            _dict['audioLanguages'] = None

        # set to None if video_codec (nullable) is None
        # and model_fields_set contains the field
        if self.video_codec is None and "video_codec" in self.model_fields_set:
            _dict['videoCodec'] = None

        # set to None if video_dynamic_range (nullable) is None
        # and model_fields_set contains the field
        if self.video_dynamic_range is None and "video_dynamic_range" in self.model_fields_set:
            _dict['videoDynamicRange'] = None

        # set to None if video_dynamic_range_type (nullable) is None
        # and model_fields_set contains the field
        if self.video_dynamic_range_type is None and "video_dynamic_range_type" in self.model_fields_set:
            _dict['videoDynamicRangeType'] = None

        # set to None if resolution (nullable) is None
        # and model_fields_set contains the field
        if self.resolution is None and "resolution" in self.model_fields_set:
            _dict['resolution'] = None

        # set to None if run_time (nullable) is None
        # and model_fields_set contains the field
        if self.run_time is None and "run_time" in self.model_fields_set:
            _dict['runTime'] = None

        # set to None if scan_type (nullable) is None
        # and model_fields_set contains the field
        if self.scan_type is None and "scan_type" in self.model_fields_set:
            _dict['scanType'] = None

        # set to None if subtitles (nullable) is None
        # and model_fields_set contains the field
        if self.subtitles is None and "subtitles" in self.model_fields_set:
            _dict['subtitles'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MediaInfoResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "audioBitrate": obj.get("audioBitrate"),
            "audioChannels": obj.get("audioChannels"),
            "audioCodec": obj.get("audioCodec"),
            "audioLanguages": obj.get("audioLanguages"),
            "audioStreamCount": obj.get("audioStreamCount"),
            "videoBitDepth": obj.get("videoBitDepth"),
            "videoBitrate": obj.get("videoBitrate"),
            "videoCodec": obj.get("videoCodec"),
            "videoFps": obj.get("videoFps"),
            "videoDynamicRange": obj.get("videoDynamicRange"),
            "videoDynamicRangeType": obj.get("videoDynamicRangeType"),
            "resolution": obj.get("resolution"),
            "runTime": obj.get("runTime"),
            "scanType": obj.get("scanType"),
            "subtitles": obj.get("subtitles")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, Optional
from whisparr.models.command import Command
from whisparr.models.command_priority import CommandPriority
from whisparr.models.command_result import CommandResult
from whisparr.models.command_status import CommandStatus
from whisparr.models.command_trigger import CommandTrigger
from typing import Optional, Set
from typing_extensions import Self

class CommandResource(BaseModel):
    """
    CommandResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    name: Optional[StrictStr] = None
    command_name: Optional[StrictStr] = Field(default=None, alias="commandName")
    message: Optional[StrictStr] = None
    body: Optional[Command] = None
    priority: Optional[CommandPriority] = None
    status: Optional[CommandStatus] = None
    result: Optional[CommandResult] = None
    queued: Optional[datetime] = None
    started: Optional[datetime] = None
    ended: Optional[datetime] = None
    duration: Optional[StrictStr] = None
    exception: Optional[StrictStr] = None
    trigger: Optional[CommandTrigger] = None
    client_user_agent: Optional[StrictStr] = Field(default=None, alias="clientUserAgent")
    state_change_time: Optional[datetime] = Field(default=None, alias="stateChangeTime")
    send_updates_to_client: Optional[StrictBool] = Field(default=None, alias="sendUpdatesToClient")
    update_scheduled_task: Optional[StrictBool] = Field(default=None, alias="updateScheduledTask")
    last_execution_time: Optional[datetime] = Field(default=None, alias="lastExecutionTime")
    __properties: ClassVar[List[str]] = ["id", "name", "commandName", "message", "body", "priority", "status", "result", "queued", "started", "ended", "duration", "exception", "trigger", "clientUserAgent", "stateChangeTime", "sendUpdatesToClient", "updateScheduledTask", "lastExecutionTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CommandResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of body
        if self.body:
            _dict['body'] = self.body.to_dict()
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if command_name (nullable) is None
        # and model_fields_set contains the field
        if self.command_name is None and "command_name" in self.model_fields_set:
            _dict['commandName'] = None

        # set to None if message (nullable) is None
        # and model_fields_set contains the field
        if self.message is None and "message" in self.model_fields_set:
            _dict['message'] = None

        # set to None if started (nullable) is None
        # and model_fields_set contains the field
        if self.started is None and "started" in self.model_fields_set:
            _dict['started'] = None

        # set to None if ended (nullable) is None
        # and model_fields_set contains the field
        if self.ended is None and "ended" in self.model_fields_set:
            _dict['ended'] = None

        # set to None if exception (nullable) is None
        # and model_fields_set contains the field
        if self.exception is None and "exception" in self.model_fields_set:
            _dict['exception'] = None

        # set to None if client_user_agent (nullable) is None
        # and model_fields_set contains the field
        if self.client_user_agent is None and "client_user_agent" in self.model_fields_set:
            _dict['clientUserAgent'] = None

        # set to None if state_change_time (nullable) is None
        # and model_fields_set contains the field
        if self.state_change_time is None and "state_change_time" in self.model_fields_set:
            _dict['stateChangeTime'] = None

        # set to None if last_execution_time (nullable) is None
        # and model_fields_set contains the field
        if self.last_execution_time is None and "last_execution_time" in self.model_fields_set:
            _dict['lastExecutionTime'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CommandResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "commandName": obj.get("commandName"),
            "message": obj.get("message"),
            "body": Command.from_dict(obj["body"]) if obj.get("body") is not None else None,
            "priority": obj.get("priority"),
            "status": obj.get("status"),
            "result": obj.get("result"),
            "queued": obj.get("queued"),
            "started": obj.get("started"),
            "ended": obj.get("ended"),
            "duration": obj.get("duration"),
            "exception": obj.get("exception"),
            "trigger": obj.get("trigger"),
            "clientUserAgent": obj.get("clientUserAgent"),
            "stateChangeTime": obj.get("stateChangeTime"),
            "sendUpdatesToClient": obj.get("sendUpdatesToClient"),
            "updateScheduledTask": obj.get("updateScheduledTask"),
            "lastExecutionTime": obj.get("lastExecutionTime")
        })
        return _obj





# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: b08981dee068e1ed23e4f45a0d8fe70ef7bf7703
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from whisparr.models.credit_type import CreditType
from whisparr.models.media_cover import MediaCover
from typing import Optional, Set
from typing_extensions import Self

class CreditResource(BaseModel):
    """
    CreditResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    person_name: Optional[StrictStr] = Field(default=None, alias="personName")
    credit_tmdb_id: Optional[StrictStr] = Field(default=None, alias="creditTmdbId")
    person_tmdb_id: Optional[StrictInt] = Field(default=None, alias="personTmdbId")
    movie_metadata_id: Optional[StrictInt] = Field(default=None, alias="movieMetadataId")
    images: Optional[List[MediaCover]] = None
    department: Optional[StrictStr] = None
    job: Optional[StrictStr] = None
    character: Optional[StrictStr] = None
    order: Optional[StrictInt] = None
    type: Optional[CreditType] = None
    __properties: ClassVar[List[str]] = ["id", "personName", "creditTmdbId", "personTmdbId", "movieMetadataId", "images", "department", "job", "character", "order", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreditResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item_images in self.images:
                if _item_images:
                    _items.append(_item_images.to_dict())
            _dict['images'] = _items
        # set to None if person_name (nullable) is None
        # and model_fields_set contains the field
        if self.person_name is None and "person_name" in self.model_fields_set:
            _dict['personName'] = None

        # set to None if credit_tmdb_id (nullable) is None
        # and model_fields_set contains the field
        if self.credit_tmdb_id is None and "credit_tmdb_id" in self.model_fields_set:
            _dict['creditTmdbId'] = None

        # set to None if images (nullable) is None
        # and model_fields_set contains the field
        if self.images is None and "images" in self.model_fields_set:
            _dict['images'] = None

        # set to None if department (nullable) is None
        # and model_fields_set contains the field
        if self.department is None and "department" in self.model_fields_set:
            _dict['department'] = None

        # set to None if job (nullable) is None
        # and model_fields_set contains the field
        if self.job is None and "job" in self.model_fields_set:
            _dict['job'] = None

        # set to None if character (nullable) is None
        # and model_fields_set contains the field
        if self.character is None and "character" in self.model_fields_set:
            _dict['character'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreditResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "personName": obj.get("personName"),
            "creditTmdbId": obj.get("creditTmdbId"),
            "personTmdbId": obj.get("personTmdbId"),
            "movieMetadataId": obj.get("movieMetadataId"),
            "images": [MediaCover.from_dict(_item) for _item in obj["images"]] if obj.get("images") is not None else None,
            "department": obj.get("department"),
            "job": obj.get("job"),
            "character": obj.get("character"),
            "order": obj.get("order"),
            "type": obj.get("type")
        })
        return _obj


